import React, { useState, useEffect } from 'react'

const faqData = [
  {
    category: 'General Information',
    questions: [
      {
        question: 'What is the minimum age requirement for tattoos?',
        answer: 'You must be 18 years or older to get a tattoo at our studio. We require valid government-issued photo ID for all clients. No exceptions.'
      },
      {
        question: 'Do you offer consultations?',
        answer: 'Yes! We offer detailed consultations for $50, which is applied toward your final tattoo cost. Consultations typically last 30-60 minutes and include design discussion, placement advice, and cost estimation.'
      },
      {
        question: 'How far in advance should I book?',
        answer: 'We recommend booking 2-4 weeks in advance for most appointments. Popular artists and larger pieces may require 6-8 weeks advance booking. Holiday seasons book up quickly.'
      },
      {
        question: 'Can I bring my own design?',
        answer: 'Absolutely! We welcome custom designs and reference images. Our artists will work with you to adapt your design for optimal tattoo application while maintaining your vision.'
      }
    ]
  },
  {
    category: 'Pricing & Payment',
    questions: [
      {
        question: 'How much do tattoos cost?',
        answer: 'Pricing varies based on size, complexity, placement, and artist. Small tattoos start at $150. Hourly rates range from $150-300. We provide detailed quotes during consultations.'
      },
      {
        question: 'What payment methods do you accept?',
        answer: 'We accept cash, credit/debit cards, and digital payments (Apple Pay, Google Pay). A 50% deposit is required to secure your appointment.'
      },
      {
        question: 'What is your deposit policy?',
        answer: 'A 50% deposit is required to book your appointment. Deposits are non-refundable but can be transferred to a new appointment with 48+ hours notice.'
      },
      {
        question: 'Do you offer payment plans?',
        answer: 'For larger pieces over $1000, we offer payment plans. Discuss options during your consultation. Full payment is required before starting the tattoo session.'
      }
    ]
  },
  {
    category: 'Appointment Policies',
    questions: [
      {
        question: 'What is your cancellation policy?',
        answer: 'Cancellations require 48+ hours notice to reschedule without penalty. Less than 48 hours notice results in deposit forfeiture. No-shows forfeit the full deposit.'
      },
      {
        question: 'Can I reschedule my appointment?',
        answer: 'Yes, with 48+ hours notice. Your deposit transfers to the new appointment. Same-day rescheduling is not permitted except for emergencies.'
      },
      {
        question: 'What should I bring to my appointment?',
        answer: 'Bring valid photo ID, reference images (if applicable), comfortable clothing that allows access to the tattoo area, and any aftercare products you prefer.'
      },
      {
        question: 'Can I bring a friend?',
        answer: 'You may bring one support person. They must remain quiet and respectful during the session. Children are not permitted in the tattoo area for safety reasons.'
      }
    ]
  },
  {
    category: 'Health & Safety',
    questions: [
      {
        question: 'What health conditions prevent me from getting tattooed?',
        answer: 'Pregnancy, certain medications (blood thinners), active skin conditions, recent illness, or compromised immune systems may require postponing. Consult your doctor if unsure.'
      },
      {
        question: 'How do you ensure safety and cleanliness?',
        answer: 'We follow strict sterilization protocols, use single-use needles and tubes, maintain autoclave sterilization records, and are regularly inspected by health authorities.'
      },
      {
        question: 'Can I get tattooed if I have allergies?',
        answer: 'Inform us of any allergies during booking. We can perform patch tests for ink allergies. Some allergies may require special precautions or prevent tattooing.'
      },
      {
        question: 'What if I have a medical condition?',
        answer: 'Disclose all medical conditions and medications during consultation. Some conditions require doctor clearance. We prioritize your safety above all else.'
      }
    ]
  },
  {
    category: 'Tattoo Process',
    questions: [
      {
        question: 'How long does a tattoo session take?',
        answer: 'Session length depends on size and complexity. Small tattoos: 1-2 hours. Medium pieces: 2-4 hours. Large pieces may require multiple sessions of 4-6 hours each.'
      },
      {
        question: 'Does getting a tattoo hurt?',
        answer: 'Pain levels vary by individual and placement. Most describe it as manageable discomfort. We provide breaks as needed and tips for pain management.'
      },
      {
        question: 'Can I see the design before the appointment?',
        answer: 'Final designs are typically completed 1-2 days before your appointment. We email designs for approval and make revisions as needed.'
      },
      {
        question: 'What if I need touch-ups?',
        answer: 'Minor touch-ups within 6 months are complimentary. Touch-ups are normal and ensure your tattoo looks its best. Schedule after complete healing (4-6 weeks).'
      }
    ]
  },
  {
    category: 'Aftercare & Healing',
    questions: [
      {
        question: 'How long does a tattoo take to heal?',
        answer: 'Surface healing: 2-3 weeks. Complete healing: 4-6 weeks. Follow aftercare instructions carefully for optimal results and to prevent complications.'
      },
      {
        question: 'What aftercare products do you recommend?',
        answer: 'We recommend fragrance-free lotions, gentle cleansers, and specific aftercare products. Avoid petroleum-based products. Detailed aftercare instructions provided after your session.'
      },
      {
        question: 'When can I swim or exercise after getting tattooed?',
        answer: 'Avoid swimming, soaking, and intense exercise for 2-3 weeks. Light exercise after 1 week is okay. Always prioritize healing over activities.'
      },
      {
        question: 'What if my tattoo gets infected?',
        answer: 'Contact us immediately if you notice signs of infection: excessive redness, heat, pus, or red streaking. Seek medical attention for severe symptoms.'
      }
    ]
  }
]

const policies = [
  {
    title: 'Age Verification',
    content: 'All clients must be 18+ years old with valid government-issued photo identification. No exceptions will be made to this policy for any reason.'
  },
  {
    title: 'Health Requirements',
    content: 'Clients must be in good health and not under the influence of drugs or alcohol. Certain medical conditions may require physician clearance.'
  },
  {
    title: 'Deposit Policy',
    content: 'A 50% deposit is required to secure all appointments. Deposits are non-refundable but transferable with 48+ hours notice.'
  },
  {
    title: 'Cancellation Policy',
    content: 'Cancellations require 48+ hours notice. Less than 48 hours notice or no-shows result in deposit forfeiture.'
  },
  {
    title: 'Design Ownership',
    content: 'Custom designs remain property of the studio and artist. Clients receive usage rights for their tattoo only.'
  },
  {
    title: 'Photography Policy',
    content: 'We may photograph tattoos for portfolio use unless client specifically opts out. Client privacy is always respected.'
  },
  {
    title: 'Liability',
    content: 'Clients assume responsibility for following aftercare instructions. The studio is not liable for complications resulting from improper aftercare.'
  },
  {
    title: 'Conduct Policy',
    content: 'Respectful behavior is required. Disruptive, inappropriate, or disrespectful behavior will result in session termination without refund.'
  }
]

function FAQ() {
  const [isLoaded, setIsLoaded] = useState(false)
  const [activeCategory, setActiveCategory] = useState(0)
  const [openQuestions, setOpenQuestions] = useState({})
  const [searchTerm, setSearchTerm] = useState('')

  useEffect(() => {
    setIsLoaded(true)
  }, [])

  const toggleQuestion = (categoryIndex, questionIndex) => {
    const key = `${categoryIndex}-${questionIndex}`
    setOpenQuestions(prev => ({
      ...prev,
      [key]: !prev[key]
    }))
  }

  const filteredFAQ = faqData.map(category => ({
    ...category,
    questions: category.questions.filter(
      q => 
        q.question.toLowerCase().includes(searchTerm.toLowerCase()) ||
        q.answer.toLowerCase().includes(searchTerm.toLowerCase())
    )
  })).filter(category => category.questions.length > 0)

  return (
    <div className="pt-16 lg:pt-20">
      {/* Header */}
      <section className="section-padding py-16 lg:py-24">
        <div className="container-max">
          <div className={`text-center transform transition-all duration-1000 ${
            isLoaded ? 'translate-y-0 opacity-100' : 'translate-y-8 opacity-0'
          }`}>
            <h1 className="text-4xl md:text-5xl lg:text-6xl font-serif font-bold mb-6">
              FAQ & Policies
            </h1>
            <p className="text-lg md:text-xl text-gray-600 max-w-3xl mx-auto mb-8">
              Everything you need to know about getting tattooed at our studio. 
              Find answers to common questions and review our policies.
            </p>
            
            {/* Search Bar */}
            <div className="max-w-md mx-auto">
              <div className="relative">
                <input
                  type="text"
                  placeholder="Search FAQ..."
                  value={searchTerm}
                  onChange={(e) => setSearchTerm(e.target.value)}
                  className="w-full px-4 py-3 pl-12 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                />
                <svg className="absolute left-4 top-1/2 transform -translate-y-1/2 w-5 h-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M21 21l-6-6m2-5a7 7 0 11-14 0 7 7 0 0114 0z" />
                </svg>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* FAQ Section */}
      <section className="section-padding pb-16">
        <div className="container-max">
          <div className="max-w-6xl mx-auto">
            {!searchTerm && (
              <>
                <h2 className="text-3xl font-serif font-bold text-center mb-12">
                  Frequently Asked Questions
                </h2>
                
                {/* Category Navigation */}
                <div className="flex flex-wrap justify-center gap-2 mb-12">
                  {faqData.map((category, index) => (
                    <button
                      key={index}
                      onClick={() => setActiveCategory(index)}
                      className={`px-4 py-2 rounded-lg text-sm font-medium transition-colors duration-300 ${
                        activeCategory === index
                          ? 'bg-black text-white'
                          : 'bg-gray-100 text-gray-600 hover:bg-gray-200'
                      }`}
                    >
                      {category.category}
                    </button>
                  ))}
                </div>
                
                {/* Active Category Questions */}
                <div className="space-y-4">
                  {faqData[activeCategory].questions.map((faq, questionIndex) => {
                    const key = `${activeCategory}-${questionIndex}`
                    const isOpen = openQuestions[key]
                    
                    return (
                      <div key={questionIndex} className="bg-white border border-gray-200 rounded-lg overflow-hidden">
                        <button
                          onClick={() => toggleQuestion(activeCategory, questionIndex)}
                          className="w-full px-6 py-4 text-left flex items-center justify-between hover:bg-gray-50 transition-colors duration-200"
                        >
                          <h3 className="font-medium text-gray-900 pr-4">{faq.question}</h3>
                          <svg
                            className={`w-5 h-5 text-gray-500 transform transition-transform duration-200 ${
                              isOpen ? 'rotate-180' : ''
                            }`}
                            fill="none"
                            stroke="currentColor"
                            viewBox="0 0 24 24"
                          >
                            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 9l-7 7-7-7" />
                          </svg>
                        </button>
                        
                        {isOpen && (
                          <div className="px-6 pb-4">
                            <p className="text-gray-600 leading-relaxed">{faq.answer}</p>
                          </div>
                        )}
                      </div>
                    )
                  })}
                </div>
              </>
            )}
            
            {/* Search Results */}
            {searchTerm && (
              <div className="space-y-8">
                <h2 className="text-2xl font-serif font-bold">
                  Search Results for "{searchTerm}"
                </h2>
                
                {filteredFAQ.length === 0 ? (
                  <div className="text-center py-12">
                    <p className="text-gray-600">No results found. Try different keywords.</p>
                  </div>
                ) : (
                  filteredFAQ.map((category, categoryIndex) => (
                    <div key={categoryIndex}>
                      <h3 className="text-xl font-serif font-semibold mb-4">{category.category}</h3>
                      <div className="space-y-4">
                        {category.questions.map((faq, questionIndex) => {
                          const key = `search-${categoryIndex}-${questionIndex}`
                          const isOpen = openQuestions[key]
                          
                          return (
                            <div key={questionIndex} className="bg-white border border-gray-200 rounded-lg overflow-hidden">
                              <button
                                onClick={() => {
                                  setOpenQuestions(prev => ({
                                    ...prev,
                                    [key]: !prev[key]
                                  }))
                                }}
                                className="w-full px-6 py-4 text-left flex items-center justify-between hover:bg-gray-50 transition-colors duration-200"
                              >
                                <h4 className="font-medium text-gray-900 pr-4">{faq.question}</h4>
                                <svg
                                  className={`w-5 h-5 text-gray-500 transform transition-transform duration-200 ${
                                    isOpen ? 'rotate-180' : ''
                                  }`}
                                  fill="none"
                                  stroke="currentColor"
                                  viewBox="0 0 24 24"
                                >
                                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 9l-7 7-7-7" />
                                </svg>
                              </button>
                              
                              {isOpen && (
                                <div className="px-6 pb-4">
                                  <p className="text-gray-600 leading-relaxed">{faq.answer}</p>
                                </div>
                              )}
                            </div>
                          )
                        })}
                      </div>
                    </div>
                  ))
                )}
              </div>
            )}
          </div>
        </div>
      </section>

      {/* Policies Section */}
      <section className="section-padding py-16 bg-gray-50">
        <div className="container-max">
          <div className="max-w-6xl mx-auto">
            <h2 className="text-3xl font-serif font-bold text-center mb-12">
              Studio Policies
            </h2>
            
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
              {policies.map((policy, index) => (
                <div key={index} className="bg-white border border-gray-200 rounded-lg p-6">
                  <h3 className="text-lg font-serif font-bold mb-3">{policy.title}</h3>
                  <p className="text-gray-600 leading-relaxed">{policy.content}</p>
                </div>
              ))}
            </div>
          </div>
        </div>
      </section>

      {/* Health & Safety */}
      <section className="section-padding py-16">
        <div className="container-max">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl font-serif font-bold text-center mb-12">
              Health & Safety Standards
            </h2>
            
            <div className="grid grid-cols-1 md:grid-cols-2 gap-8">
              <div className="space-y-6">
                <div>
                  <h3 className="text-xl font-serif font-semibold mb-3">Sterilization</h3>
                  <ul className="space-y-2 text-gray-600">
                    <li>• Autoclave sterilization of all reusable equipment</li>
                    <li>• Single-use needles and tubes for every client</li>
                    <li>• Fresh ink caps and barriers for each session</li>
                    <li>• Regular spore testing and documentation</li>
                  </ul>
                </div>
                
                <div>
                  <h3 className="text-xl font-serif font-semibold mb-3">Licensing</h3>
                  <ul className="space-y-2 text-gray-600">
                    <li>• State-licensed tattoo establishment</li>
                    <li>• All artists hold current tattoo licenses</li>
                    <li>• Regular health department inspections</li>
                    <li>• Bloodborne pathogen certification</li>
                  </ul>
                </div>
              </div>
              
              <div className="space-y-6">
                <div>
                  <h3 className="text-xl font-serif font-semibold mb-3">Hygiene Protocols</h3>
                  <ul className="space-y-2 text-gray-600">
                    <li>• Hand washing and glove changes between clients</li>
                    <li>• Surface disinfection with hospital-grade cleaners</li>
                    <li>• Proper waste disposal procedures</li>
                    <li>• Clean linens and disposable covers</li>
                  </ul>
                </div>
                
                <div>
                  <h3 className="text-xl font-serif font-semibold mb-3">Quality Assurance</h3>
                  <ul className="space-y-2 text-gray-600">
                    <li>• Premium tattoo inks and equipment only</li>
                    <li>• Regular equipment maintenance and calibration</li>
                    <li>• Continuous education and training</li>
                    <li>• Client feedback and improvement processes</li>
                  </ul>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Contact for Questions */}
      <section className="section-padding py-16 bg-gray-900 text-white">
        <div className="container-max">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-3xl font-serif font-bold mb-6">
              Still Have Questions?
            </h2>
            <p className="text-lg text-gray-300 mb-8">
              Can't find what you're looking for? Our team is here to help.
            </p>
            
            <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
              <div className="bg-gray-800 rounded-lg p-6">
                <svg className="w-8 h-8 text-accent mx-auto mb-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M3 5a2 2 0 012-2h3.28a1 1 0 01.948.684l1.498 4.493a1 1 0 01-.502 1.21l-2.257 1.13a11.042 11.042 0 005.516 5.516l1.13-2.257a1 1 0 011.21-.502l4.493 1.498a1 1 0 01.684.949V19a2 2 0 01-2 2h-1C9.716 21 3 14.284 3 6V5z" />
                </svg>
                <h3 className="font-semibold mb-2">Call Us</h3>
                <p className="text-gray-300">(555) 123-4567</p>
              </div>
              
              <div className="bg-gray-800 rounded-lg p-6">
                <svg className="w-8 h-8 text-accent mx-auto mb-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M3 8l7.89 4.26a2 2 0 002.22 0L21 8M5 19h14a2 2 0 002-2V7a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z" />
                </svg>
                <h3 className="font-semibold mb-2">Email Us</h3>
                <p className="text-gray-300">info@studioname.com</p>
              </div>
              
              <div className="bg-gray-800 rounded-lg p-6">
                <svg className="w-8 h-8 text-accent mx-auto mb-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M8 7V3m8 4V3m-9 8h10M5 21h14a2 2 0 002-2V7a2 2 0 00-2-2H5a2 2 0 00-2 2v12a2 2 0 002 2z" />
                </svg>
                <h3 className="font-semibold mb-2">Book Consultation</h3>
                <a href="/booking" className="text-accent hover:underline">Schedule Now</a>
              </div>
            </div>
          </div>
        </div>
      </section>
    </div>
  )
}

export default FAQ